@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,16 +32,50 @@ LF = '\n'
 CRLF = '\r\n'
 
 
-def GetDefaultStyleForDir(dirname):
+def _GetExcludePatternsFromFile(filename):
+  """Get a list of file patterns to ignore."""
+  ignore_patterns = []
+  # See if we have a .yapfignore file.
+  if os.path.isfile(filename) and os.access(filename, os.R_OK):
+    with open(filename, 'r') as fd:
+      for line in fd:
+        if line.strip() and not line.startswith('#'):
+          ignore_patterns.append(line.strip())
+
+    if any(e.startswith('./') for e in ignore_patterns):
+      raise errors.YapfError('path in .yapfignore should not start with ./')
+
+  return ignore_patterns
+
+
+def GetExcludePatternsForDir(dirname):
+  """Return patterns of files to exclude from ignorefile in a given directory.
+
+  Looks for .yapfignore in the directory dirname.
+
+  Arguments:
+    dirname: (unicode) The name of the directory.
+
+  Returns:
+    A List of file patterns to exclude if ignore file is found, otherwise empty
+    List.
+  """
+  ignore_file = os.path.join(dirname, '.yapfignore')
+  return _GetExcludePatternsFromFile(ignore_file)
+
+
+def GetDefaultStyleForDir(dirname, default_style=style.DEFAULT_STYLE):
   """Return default style name for a given directory.
 
   Looks for .style.yapf or setup.cfg in the parent directories.
 
   Arguments:
     dirname: (unicode) The name of the directory.
+    default_style: The style to return if nothing is found. Defaults to the
+                   global default style ('pep8') unless otherwise specified.
 
   Returns:
-    The filename if found, otherwise return the global default (pep8).
+    The filename if found, otherwise return the default style.
   """
   dirname = os.path.abspath(dirname)
   while True:
@@ -52,23 +86,27 @@ def GetDefaultStyleForDir(dirname):
 
     # See if we have a setup.cfg file with a '[yapf]' section.
     config_file = os.path.join(dirname, style.SETUP_CONFIG)
-    if os.path.exists(config_file):
-      with open(config_file) as fd:
+    try:
+      fd = open(config_file)
+    except IOError:
+      pass  # It's okay if it's not there.
+    else:
+      with fd:
         config = py3compat.ConfigParser()
         config.read_file(fd)
         if config.has_section('yapf'):
           return config_file
 
-    dirname = os.path.dirname(dirname)
     if (not dirname or not os.path.basename(dirname) or
         dirname == os.path.abspath(os.path.sep)):
       break
+    dirname = os.path.dirname(dirname)
 
   global_file = os.path.expanduser(style.GLOBAL_STYLE)
   if os.path.exists(global_file):
     return global_file
 
-  return style.DEFAULT_STYLE
+  return default_style
 
 
 def GetCommandLineFiles(command_line_file_list, recursive, exclude):
@@ -114,31 +152,46 @@ def LineEnding(lines):
 
 def _FindPythonFiles(filenames, recursive, exclude):
   """Find all Python files."""
+  if exclude and any(e.startswith('./') for e in exclude):
+    raise errors.YapfError("path in '--exclude' should not start with ./")
+
   python_files = []
   for filename in filenames:
+    if filename != '.' and exclude and IsIgnored(filename, exclude):
+      continue
     if os.path.isdir(filename):
       if recursive:
         # TODO(morbo): Look into a version of os.walk that can handle recursion.
-        python_files.extend(
-            os.path.join(dirpath, f)
-            for dirpath, _, filelist in os.walk(filename)
-            for f in filelist
-            if IsPythonFile(os.path.join(dirpath, f)))
+        excluded_dirs = []
+        for dirpath, _, filelist in os.walk(filename):
+          if dirpath != '.' and exclude and IsIgnored(dirpath, exclude):
+            excluded_dirs.append(dirpath)
+            continue
+          elif any(dirpath.startswith(e) for e in excluded_dirs):
+            continue
+          for f in filelist:
+            filepath = os.path.join(dirpath, f)
+            if exclude and IsIgnored(filepath, exclude):
+              continue
+            if IsPythonFile(filepath):
+              python_files.append(filepath)
       else:
         raise errors.YapfError(
             "directory specified without '--recursive' flag: %s" % filename)
     elif os.path.isfile(filename):
       python_files.append(filename)
 
-  if exclude:
-    return [
-        f for f in python_files
-        if not any(fnmatch.fnmatch(f, p) for p in exclude)
-    ]
-
   return python_files
 
 
+def IsIgnored(path, exclude):
+  """Return True if filename matches any patterns in exclude."""
+  path = path.lstrip('/')
+  while path.startswith('./'):
+    path = path[2:]
+  return any(fnmatch.fnmatch(path, e.rstrip('/')) for e in exclude)
+
+
 def IsPythonFile(filename):
   """Return True if filename is a Python file."""
   if os.path.splitext(filename)[1] == '.py':
@@ -163,8 +216,8 @@ def IsPythonFile(filename):
   try:
     with py3compat.open_with_encoding(
         filename, mode='r', encoding=encoding) as fd:
-      first_line = fd.readlines()[0]
-  except (IOError, IndexError):
+      first_line = fd.readline(256)
+  except IOError:
     return False
 
   return re.match(r'^#!.*\bpython[23]?\b', first_line)
